@@ -6,11 +6,11 @@ Business::Shipping::Shipment - Abstract class
 
 =head1 VERSION
 
-$Rev: 190 $
+$Rev: 194 $
 
 =cut
 
-$VERSION = do { my $r = q$Rev: 190 $; $r =~ /\d+/; $&; };
+$VERSION = do { my $r = q$Rev: 194 $; $r =~ /\d+/; $&; };
 
 =head1 DESCRIPTION
 
@@ -50,7 +50,7 @@ use Business::Shipping::Util;
 use Class::MethodMaker 2.0
     [
       new    => [ { -hash => 1 }, 'new' ],
-      scalar => [ qw/ current_package_index service from_zip from_city  to_zip to_city /   
+      scalar => [ qw/current_package_index from_zip from_city to_zip to_city/   
                 ],
       array  => [ { -type => 'Business::Shipping::Package' }, 'packages' ],
       scalar => [ { -static => 1, -default => 'packages=>Business::Shipping::Package' }, 'Has_a' ],
